/**
  *  \file planetscentral/u/t_host_schedule.cc
  */

#include "planetscentral/u/t_host_schedule.h"
#include "planetscentral/host/schedule.h"

void
HostScheduleTestSuite::testHostDate()
{
    Schedule sch;
    sch.setType(Schedule::Weekly);
    sch.setWeekDays(SmallSet<int8_t>::fromInteger(17));  // Thu+Sun
    sch.setDaytime(360);                                 // 6:00
    sch.setHostEarly(1);
    sch.setHostDelay(30);
    sch.setHostLimit(360);      // 6 hours

    const int32_t nov22 = 22559400;  // Thu Nov 22 06:00:00 2012
    const int32_t nov25 = 22563720;  // Sun Nov 25 06:00:00 2012
    const int32_t nov29 = 22569480;  // Thu Nov 29 06:00:00 2012
    const int32_t dec02 = 22573800;  // Sun Dec  2 06:00:00 2012

    // Regular progression
    TS_ASSERT_EQUALS(sch.getNextHost(nov22), nov25);
    TS_ASSERT_EQUALS(sch.getNextHost(nov25), nov29);

    // With 5 hour delay
    TS_ASSERT_EQUALS(sch.getNextHost(nov22 + 300), nov25);
    TS_ASSERT_EQUALS(sch.getNextHost(nov25 + 300), nov29);

    // With 6 hour delay
    TS_ASSERT_EQUALS(sch.getNextHost(nov22 + 360), nov25);
    TS_ASSERT_EQUALS(sch.getNextHost(nov25 + 360), nov29);

    // With 6:01 hour delay
    TS_ASSERT_EQUALS(sch.getNextHost(nov22 + 361), nov29);
    TS_ASSERT_EQUALS(sch.getNextHost(nov25 + 361), dec02);

    // Virtual host
    TS_ASSERT_EQUALS(sch.getPreviousVirtualHost(nov25), nov22);
    TS_ASSERT_EQUALS(sch.getPreviousVirtualHost(nov25+1), nov22);
    TS_ASSERT_EQUALS(sch.getPreviousVirtualHost(nov25+360), nov22);
    TS_ASSERT_EQUALS(sch.getPreviousVirtualHost(nov25+361), nov25);
    TS_ASSERT_EQUALS(sch.getPreviousVirtualHost(nov25-1), nov22);
    TS_ASSERT_EQUALS(sch.getPreviousVirtualHost(nov25-360), nov22);
}
